/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.dynamic.data.mapping.form.evaluator.internal.functions;

import com.liferay.dynamic.data.mapping.form.evaluator.DDMFormFieldEvaluationResult;
import com.liferay.dynamic.data.mapping.form.field.type.DDMFormFieldTypeServicesTracker;
import com.liferay.dynamic.data.mapping.form.field.type.DDMFormFieldValueAccessor;
import com.liferay.dynamic.data.mapping.model.DDMFormField;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author Leonardo Barros
 */
public class GetValueFunction extends BaseDDMFormRuleFunction {

	public GetValueFunction(
		Map<String, DDMFormField> ddmFormFields,
		Map<String, List<DDMFormFieldEvaluationResult>>
			ddmFormFieldEvaluationResultsMap,
		DDMFormFieldTypeServicesTracker ddmFormFieldTypeServicesTracker) {

		super(ddmFormFieldEvaluationResultsMap);

		_ddmFormFields = ddmFormFields;
		_ddmFormFieldTypeServicesTracker = ddmFormFieldTypeServicesTracker;
	}

	@Override
	public Object evaluate(Object... parameters) {
		if (parameters.length != 1) {
			throw new IllegalArgumentException("One parameter is expected");
		}

		String ddmFormFieldName = parameters[0].toString();

		List<DDMFormFieldEvaluationResult> ddmFormFieldEvaluationResults =
			getDDMFormFieldEvaluationResults(ddmFormFieldName);

		Stream<DDMFormFieldEvaluationResult>
			ddmFormFieldEvaluationResultStream =
				ddmFormFieldEvaluationResults.stream();

		Stream<Object> valueStream = ddmFormFieldEvaluationResultStream.map(
			result -> map(ddmFormFieldName, result.isVisible() ? result.getValue() : ""));

		Set<Object> valuesSet = valueStream.collect(Collectors.toSet());

		Object[] values = valuesSet.toArray();

		if (values.length == 1) {
			return values[0];
		}

		return values;
	}

	protected Object map(String ddmFormFieldName, Object value) {
		DDMFormField ddmFormField = _ddmFormFields.get(ddmFormFieldName);

		if (ddmFormField == null) {
			return value;
		}

		DDMFormFieldValueAccessor<?> ddmFormFieldValueAccessor =
			_ddmFormFieldTypeServicesTracker.getDDMFormFieldValueAccessor(
				ddmFormField.getType());

		if (ddmFormFieldValueAccessor == null) {
			return value;
		}

		return ddmFormFieldValueAccessor.map(value);
	}

	private final Map<String, DDMFormField> _ddmFormFields;
	private final DDMFormFieldTypeServicesTracker
		_ddmFormFieldTypeServicesTracker;

}